# -*- coding: utf-8 -*-
from zope.interface import implements
from Products.CMFPlone.interfaces import INonInstallable


class HiddenProfiles(object):
    implements(INonInstallable)

    def getNonInstallableProfiles(self):
        return ['collective.atomrss:uninstall']



# -*- coding: utf-8 -*-
from plone.app.testing import PloneWithPackageLayer
from plone.app.testing import IntegrationTesting
from plone.app.testing import FunctionalTesting

# from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE

import collective.atomrss


COLLECTIVE_ATOMRSS = PloneWithPackageLayer(
    zcml_package=collective.atomrss,
    zcml_filename='testing.zcml',
    gs_profile_id='collective.atomrss:testing',
    name='COLLECTIVE_ATOMRSS'
)

COLLECTIVE_ATOMRSS_INTEGRATION = IntegrationTesting(
    bases=(COLLECTIVE_ATOMRSS, ),
    name="COLLECTIVE_ATOMRSS_INTEGRATION"
)

COLLECTIVE_ATOMRSS_FUNCTIONAL = FunctionalTesting(
    bases=(COLLECTIVE_ATOMRSS, ),
    name="COLLECTIVE_ATOMRSS_FUNCTIONAL"
)

# COLLECTIVE_ATOMRSS_ROBOT_TESTING = FunctionalTesting(
#     bases=(
#         COLLECTIVE_ATOMRSS,
#         REMOTE_LIBRARY_BUNDLE_FIXTURE,
#         z2.ZSERVER_FIXTURE),
#     name="COLLECTIVE_ATOMRSS_ROBOT_TESTING")



# -*- coding: utf-8 -*-
"""Init and utils."""

from zope.i18nmessageid import MessageFactory

_ = MessageFactory('collective.atomrss')


def initialize(context):
    """Initializer called when used as a Zope 2 product."""



# -*- coding: utf-8 -*-
"""Legacy install/uninstall-methods to guard from re-installing/uninstalling"""
from Products.CMFCore.utils import getToolByName


def uninstall(context, reinstall=False):
    if not reinstall:
        setup_tool = getToolByName(context, 'portal_setup')
        setup_tool.runAllImportStepsFromProfile(
            'profile-collective.atomrss:uninstall', purge_old=False)



# -*- coding: utf-8 -*-
from plone.app.contenttypes.interfaces import IEvent
from plone.app.contenttypes.interfaces import INewsItem
from Products.ATContentTypes.interfaces import IATEvent
from Products.ATContentTypes.interfaces import IATNewsItem
from Products.CMFPlone.browser.syndication.adapters import BaseItem
from Products.CMFPlone.browser.syndication.settings import FEED_SETTINGS_KEY
from Products.CMFPlone.browser.syndication.settings import FeedSettings
from Products.CMFPlone.interfaces.syndication import IFeed
from Products.CMFPlone.interfaces.syndication import IFeedSettings
from Products.CMFPlone.interfaces.syndication import ISyndicatable
from zope.annotation.interfaces import IAnnotations
from zope.component import adapts
from zope.interface import implements


class AtomFeedSettings(FeedSettings):
    """ Change default value for feed : atom.xml is first and render_body True
    """
    implements(IFeedSettings)
    adapts(ISyndicatable)

    def __init__(self, context):
        super(AtomFeedSettings, self).__init__(context)
        annotations = IAnnotations(context)

        if 'render_body' not in self._metadata.keys():
            self._metadata['render_body'] = True
            annotations[FEED_SETTINGS_KEY] = self._metadata
        if 'feed_types' not in self._metadata.keys():
            self._metadata['feed_types'] = (u'atom.xml', u'RSS', u'rss.xml')
            annotations[FEED_SETTINGS_KEY] = self._metadata


class NewsFeedItem(BaseItem):
    adapts(INewsItem, IFeed)

    @property
    def image_obj(self):
        image_field = 'image'
        field = getattr(self.context, image_field)
        # Check if there is a leadImage and if it's not empty
        if field is not None and field.data:
            scaling = 'preview'
            img_url = '{0}/@@images/{1}/{2}'.format(
                self.context.absolute_url(),
                image_field,
                scaling)
            img_size = field.size
            img_type = field.contentType
            img_title = field.filename
            return {
                'url': img_url,
                'size': img_size,
                'type': img_type,
                'title': img_title
            }
        else:
            return False

    @property
    def image_url(self):
        """ backward compatibilites """
        image_obj = self.image_obj()
        if not image_obj:
            return False
        else:
            return image_obj.get('url')


class ATNewsFeedItem(BaseItem):
    adapts(IATNewsItem, IFeed)

    @property
    def image_url(self):
        image_field = 'image'
        scaling = 'preview'
        return '{0}/{1}_{2}'.format(
            self.context.absolute_url(),
            image_field,
            scaling)

    @property
    def image_obj(self):
        """ Used to dexterity content types """
        return False


class EventFeedItem(BaseItem):
    adapts(IEvent, IFeed)

    def formated_date(self, date):
        return date.strftime('%d/%m/%Y %H:%M')

    @property
    def startdate(self):
        return getattr(self.context, 'start', '')

    @property
    def enddate(self):
        return getattr(self.context, 'end', '')

    @property
    def contactname(self):
        return getattr(self.context, 'contact_name', '')

    @property
    def contactemail(self):
        return getattr(self.context, 'contact_email', '')

    @property
    def contactphone(self):
        return getattr(self.context, 'contact_phone', '')

    @property
    def location(self):
        return self.context.location

    @property
    def eventurl(self):
        return getattr(self.context, 'event_url', '')

    @property
    def image_obj(self):
        image_field = 'image'
        field = getattr(self.context, image_field)
        # Check if there is a leadImage and if it's not empty
        if field is not None and field.data:
            scaling = 'preview'
            img_url = '{0}/@@images/{1}/{2}'.format(
                self.context.absolute_url(),
                image_field,
                scaling)
            img_size = field.size
            img_type = field.contentType
            img_title = field.filename
            return {
                'url': img_url,
                'size': img_size,
                'type': img_type,
                'title': img_title
            }
        else:
            return False

    @property
    def image_url(self):
        """ backward compatibilites """
        image_obj = self.image_obj()
        if not image_obj:
            return False
        else:
            return image_obj.get('url')


class ATEventFeedItem(BaseItem):
    adapts(IATEvent, IFeed)

    def formated_date(self, date):
        from datetime import datetime
        if isinstance(date, datetime):
            return date.strftime('%d/%m/%Y %H:%M')
        else:
            try:
                mydate = date.split(' GMT')[0]
                dt = datetime.strptime(mydate, '%Y/%m/%d %H:%M:%S')
                return dt.strftime('%d/%m/%Y %H:%M')
            except:
                return date

    @property
    def startdate(self):
        return str(self.context.startDate)

    @property
    def enddate(self):
        return str(self.context.endDate)

    @property
    def contactname(self):
        return self.context.contact_name()

    @property
    def contactemail(self):
        return self.context.contact_email()

    @property
    def contactphone(self):
        return self.context.contact_phone()

    @property
    def location(self):
        return self.context.location

    @property
    def eventurl(self):
        return self.context.event_url()

    @property
    def image_url(self):
        image_field = 'leadImage'
        field = self.context.getField(image_field)
        # Check if there is a leadImage and if it's not empty
        if field is not None:
            value = field.get(self.context)
            if not bool(value):
                return False
        else:
            return False
        scaling = 'preview'
        return '{0}/{1}_{2}'.format(
            self.context.absolute_url(),
            image_field,
            scaling)

    @property
    def image_obj(self):
        """ Used to dexterity content types """
        return False



# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

import os


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = \
    read('README.rst') + \
    read('CHANGES.rst')

setup(
    name='collective.atomrss',
    version='0.1.10',
    description="Package extends Plone syndication for using Atom RSS by default. It also added some field as events date, contentlead image into rss feed.",
    long_description=long_description,
    # Get more from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
    ],
    keywords='Plone Python Atom RSS',
    author='Benoît Suttor',
    author_email='bsuttor@imio.be',
    url='http://pypi.python.org/pypi/collective.atomrss',
    license='BSD',
    packages=find_packages('src', exclude=['ez_setup']),
    namespace_packages=['collective'],
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Plone',
        'setuptools',
        'plone.api',
        'plone.app.contenttypes',
    ],
    extras_require={
        'test': [
            'plone.app.robotframework',
        ],
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)



# -*- coding: utf-8 -*-
import unittest
from plone.browserlayer import utils
from zope.event import notify
from zope.traversing.interfaces import BeforeTraverseEvent

from Products.CMFCore.utils import getToolByName

from collective.atomrss.interfaces import ICollectiveAtomrssLayer
from collective.atomrss.testing import COLLECTIVE_ATOMRSS_INTEGRATION
from Products.CMFPlone.interfaces.syndication import IFeedSettings


class TestSetup(unittest.TestCase):
    layer = COLLECTIVE_ATOMRSS_INTEGRATION

    def setUp(self):
        self.app = self.layer['app']
        self.portal = self.layer['portal']
        self.request = self.layer['request']
        notify(BeforeTraverseEvent(self.portal, self.request))
        self.pid = 'collective.atomrss'

    def test_product_is_installed(self):
        """ Validate that our products GS profile has been run and the product
            installed
        """
        qi_tool = getToolByName(self.portal, 'portal_quickinstaller')
        installed = [p['id'] for p in qi_tool.listInstalledProducts()]
        self.assertTrue(
            self.pid in installed,
            'package appears not to have been installed')

    def test_browserlayer(self):
        """Test that ICollectiveAtomrssLayer is registered."""
        self.assertIn(ICollectiveAtomrssLayer, utils.registered_layers())

    def test_uninstall(self):
        """Test if collective.atomrss is cleanly uninstalled."""
        qi_tool = getToolByName(self.portal, 'portal_quickinstaller')
        qi_tool.uninstallProducts([self.pid])
        self.assertFalse(qi_tool.isProductInstalled(self.pid))
        self.assertNotIn(ICollectiveAtomrssLayer, utils.registered_layers())
